**********************************************************************
* Last update: 2020/10/23
* Master do file for 
* Marriage Intentions, Desires & Pathways to Later and Less Marriage in Japan
* Authors:
* James M. Raymo
* Fumiya Uchikoshi, uchikoshi@princeton.edu (responsible for this code)
* Shohei Yoda
**********************************************************************
capture cd "Replication_DR"

**********************************************************************
* Create dta files
**********************************************************************

qui import delimited PY090.csv,clear
qui destring , replace force
qui save "PY090.dta",replace

qui import delimited PM090.csv,clear
qui destring , replace force
qui save "PM090.dta",replace

qui append using PY090.dta,force

save JLPSWave1-9wide.dta,replace

**********************************************************************
* Set up
**********************************************************************

log using `"`path'JLPS_Marriage_Desire_DR`=subinstr("`c(current_date)'"," ","",.))'.log"', replace
set more off
*do "/Users/fumiyau/Dropbox/99.DoFiles/JLPS/0.Original.do"
use "JLPSWave1-9wide.dta",clear

**********************************************************************
* Run do files for creating the dataset
**********************************************************************

do "1.DataConst.do"
do "2.DataEdit.do"
do "3.Labeling.do" 

**********************************************************************
* Table 2 Descriptive statistics, by sex at wave 1 JLPS 
**********************************************************************
*use "0.Data/JLPS-Long.dta",replace
use "JLPSWave1-9long.dta",replace
local variables "intmar1 intmar2 intmar3 intmar4 intmar5 age redu1 redu2 redu3 type1 type2 type3 type4 cores citysize1 citysize2 citysize3"

estpost tabstat `variables' if sex == 1 & wave == 1, statistics(n mean sd min max) columns(statistics) 
esttab . using Results/Descriptive/DescbyMenW1.csv, replace cells("mean(fmt(3)) sd(fmt(3)) min(fmt(0)) max(fmt(0))")  wide label

estpost tabstat `variables' if sex == 2 & wave == 1, statistics(n mean sd min max) columns(statistics) 
esttab . using Results/Descriptive/DescbyWomenW1.csv, replace cells("mean(fmt(3)) sd(fmt(3)) min(fmt(0)) max(fmt(0))")  wide label

**********************************************************************
* Table 3: Marriage desires at wave t and wave t+1 
**********************************************************************
xtset id wave
xttrans intmar,freq

**********************************************************************
* Tables 4,5: Estimated coefficients for transition to first marriage 
**********************************************************************

do "4.Regression.do"

**********************************************************************
* Figures 4,5: Trajectories of men and women’s marriage desires 
* Appendix Table 2: Distribution of marriage desire trajectory groups
**********************************************************************

do "5.Trajectory.do"

log close
