***********************************
* Load dataset
***********************************
use "JLPSWave1-9long.dta",replace

/**********************************************************************/
/*  SECTION 1: Variable construction  			
    Notes: */
/**********************************************************************/

/*----------------------------------------------------*/
   /* [>   1.  Variable edit   <] */ 
/*----------------------------------------------------*/

recode intmar 8=.
sort id wave
**Create lagged variable
by id: gen intmar_1=intmar[_n-1]
by id: gen intmar_2=intmar_1[_n-1]
**Create intention at wave 1
by id: gen intmar_w1x=intmar if wave == 1
by id: egen intmar_w1 = max(intmar_w1x)
**Labeling
recode intmar_w1 intmar_1 intmar_2 (5=4)
label define intmarl 8"Married" 1 "Definitely want to marry" 2 "Want to marry if possible" 3 "Don't care if marry or not" 4 "Not thinking about marriage/Don't want to marry" ,replace
label values intmar_w1 intmarl
label values intmar_1 intmarl
label values intmar_2 intmarl
**Create dummy variables
qui tabulate intmar_1, generate(intmar_1_)
qui tabulate intmar_2, generate(intmar_2_)
qui tabulate intmar_w1, generate(intmar_w1_)
**Recoding
recode marstat 2=0 1=1, gen(mar_1)
**censor people when they marry
by id: gen marsum = sum(mar_1)
keep if marsum == 0 | marsum == 1

gen mar_2 = mar_1

/*----------------------------------------------------*/
   /* [>   2.  Labeling   <] */ 
/*----------------------------------------------------*/

label variable mar_1 "Male"
label variable mar_2 "Female"

label variable intmar_1_1 "Definitely want to marry (t-1)"
label variable intmar_1_2 "Want to marry if possible (t-1)"
label variable intmar_1_3 "Don't care if marry or not (t-1)"
label variable intmar_1_4 "Not thinking about marriage/Don't want to marry (t-1)"
label variable intmar_2_1 "Definitely want to marry (t-2)"
label variable intmar_2_2 "Want to marry if possible (t-2)"
label variable intmar_2_3 "Don't care if marry or not (t-2)"
label variable intmar_2_4 "Not thinking about marriage/Don't want to marry (t-2)"
label variable intmar_w1_1 "Definitely want to marry (wave 1)"
label variable intmar_w1_2 "Want to marry if possible (wave 1)"
label variable intmar_w1_3 "Don't care if marry or not (wave 1)"
label variable intmar_w1_4 "Not thinking about marriage/Don't want to marry (wave 1)"

**Create duration at risk
gen risk = age - 18
gen agesq = age*age
label variable risk "Duration at risk"
label variable age "Age"
label variable agesq "Age (square)"

/*----------------------------------------------------*/
   /* [>   3.  Sample restriction   <] */ 
/*----------------------------------------------------*/

keep if intmar_1 ~=. & redu ~=. & coresx ~=. & typex ~=.

/*----------------------------------------------------*/
   /* [>   4.  Create constraints   <] */ 
/*----------------------------------------------------*/

constraint define 1 _b[intmar_1_4]=0
constraint define 3 _b[c.redu2#c.intmar_1_3]=0
constraint define 4 _b[c.redu3#c.intmar_1_3]=0
constraint define 5 _b[c.redu2#c.intmar_1_4]=0

/**********************************************************************/
/*  SECTION 2: Regression results 			
    Notes: */
/**********************************************************************/

/*----------------------------------------------------*/
   /* [>   1.  Education   <] */ 
/*----------------------------------------------------*/

cloglog mar_1 c.age##c.age coresx citysizex2 citysizex3 redu2 redu3 if sex == 1 & intmar_1_4 ~= 1
est sto model11
cloglog mar_1 c.age##c.age coresx citysizex2 citysizex3 redu2 redu3 intmar_1_2 intmar_1_3  if sex == 1 & intmar_1_4 ~= 1, constraints(1)
est sto model21
cloglog mar_1 c.age##c.age coresx citysizex2 citysizex3 redu2 redu3 intmar_1_2 intmar_1_3  c.redu2#c.intmar_1_2 c.redu2#c.intmar_1_3 c.redu3#c.intmar_1_2 c.redu3#c.intmar_1_3 if sex == 1 & intmar_1_4 ~= 1, constraints(1 2 3)
est sto model31

cloglog mar_2 c.age##c.age coresx citysizex2 citysizex3 redu2 redu3 if sex == 2
est sto model12
cloglog mar_2 c.age##c.age coresx citysizex2 citysizex3 redu2 redu3 intmar_1_2 intmar_1_3 intmar_1_4 if sex == 2
est sto model22
cloglog mar_2 c.age##c.age coresx citysizex2 citysizex3 redu2 redu3 intmar_1_2 intmar_1_3 intmar_1_4 c.redu2#c.intmar_1_2 c.redu2#c.intmar_1_3 c.redu3#c.intmar_1_2 c.redu3#c.intmar_1_3 c.redu3#c.intmar_1_4 if sex == 2 , constraints(5)
est sto model32

esttab model11 model21 model31 model12 model22 model32 using `"`path'Results/Regression/Cloglog`=subinstr("`c(current_date)'"," ","",.)'[Edu].csv"', ci scalar(N ll) nostar b(2) label  replace noomitted title(Cloglog models (those unmarried at wave 3))

/*----------------------------------------------------*/
   /* [>   2.  Employment  <] */ 
/*----------------------------------------------------*/

cloglog mar_1 c.age##c.age coresx citysizex2 citysizex3 typex1 typex3 typex4 if sex == 1 & intmar_1_4 ~= 1
est sto model11
cloglog mar_1 c.age##c.age coresx citysizex2 citysizex3 typex1 typex3 typex4 intmar_1_2 intmar_1_3  if sex == 1 & intmar_1_4 ~= 1, constraints(1)
est sto model21
cloglog mar_1 c.age##c.age coresx citysizex2 citysizex3 typex1 typex3 typex4 intmar_1_2 intmar_1_3  c.typex1#c.intmar_1_2 c.typex1#c.intmar_1_3 c.typex3#c.intmar_1_2 c.typex4#c.intmar_1_2 if sex == 1 & intmar_1_4 ~= 1, constraints(1 2 3)
est sto model31

cloglog mar_2 c.age##c.age coresx citysizex2 citysizex3 typex1 typex3 typex4 if sex == 2
est sto model12
cloglog mar_2 c.age##c.age coresx citysizex2 citysizex3 typex1 typex3 typex4 intmar_1_2 intmar_1_3 intmar_1_4 if sex == 2
est sto model22
cloglog mar_2 c.age##c.age coresx citysizex2 citysizex3 typex1 typex3 typex4 intmar_1_2 intmar_1_3 intmar_1_4 c.typex1#c.intmar_1_2 c.typex1#c.intmar_1_3 c.typex3#c.intmar_1_2 c.typex4#c.intmar_1_2 c.typex4#c.intmar_1_3 if sex == 2 , constraints(5)
est sto model32

esttab model11 model21 model31 model12 model22 model32 using `"`path'Results/Regression/Cloglog`=subinstr("`c(current_date)'"," ","",.)'[Emp].csv"', ci scalar(N ll) nostar b(2) label  replace noomitted title(Cloglog models (those unmarried at wave 3))



